@@ -43,21 +43,25 @@
  *
  * Examples:
  *   Release        _VERSION  _FULL_VERSION
- *   7.5.0           7.5.0     7.5.0
- *   7.5.1 beta 1    7.5.1     7.5.1b1
- *   7.5.1 patch 1   7.5.1.1   7.5.1p1
+ *   8.2            8.2       8.2  
+ *   8.2 beta 1     8.2       7.1b1
+ *   8.2 patch 1    8.2       8.2.1  
  */
 
-#define TCLX_PATCHLEVEL      0
+#define TCLX_PATCHLEVEL      1
 
-#define TCLX_VERSION        "8.1.0"
-#define TCLX_FULL_VERSION   "8.1.0"
+#define TCLX_VERSION        "8.1"
+#define TCLX_FULL_VERSION   "8.1.1"
 
-#define TKX_VERSION         "8.1.0"
-#define TKX_FULL_VERSION    "8.1.0"
+#define TKX_VERSION         "8.1"
+#define TKX_FULL_VERSION    "8.1.1"
 
 #define TCLX_DEBUG
 
+/* Removed TclX_Main, use macro instead */
+#define TclX_Main(argc, argv, proc) \
+    TclX_MainEx(argc, argv, proc, Tcl_CreateInterp())
+
 /*
  * Generic void pointer.
  */
@@ -107,10 +111,10 @@ TclXRuntimeInit _ANSI_ARGS_((Tcl_Interp *interp,
 /*
  * Exported TclX initialization functions.
  */
-EXTERN void
-TclX_Main _ANSI_ARGS_((int              argc,
-                       char           **argv,
-                       Tcl_AppInitProc *appInitProc));
+
+EXTERN void		TclX_MainEx _ANSI_ARGS_((int argc, char ** argv, 
+				Tcl_AppInitProc * appInitProc, 
+				Tcl_Interp * interp));
 
 EXTERN int
 Tclx_Init _ANSI_ARGS_((Tcl_Interp *interp));
@@ -118,6 +122,11 @@ Tclx_Init _ANSI_ARGS_((Tcl_Interp *interp));
 EXTERN int
 Tclx_SafeInit _ANSI_ARGS_((Tcl_Interp *interp));
 
+EXTERN char*
+TclX_InitTclStubs _ANSI_ARGS_((Tcl_Interp *interp,
+			       char       *version,
+			       int         exact));
+
 EXTERN int
 Tclx_InitStandAlone _ANSI_ARGS_((Tcl_Interp *interp));
 
@@ -163,6 +172,9 @@ TclX_SplitWinCmdLine _ANSI_ARGS_((int    *argcPtr,
 /*
  * Exported utility functions.
  */
+EXTERN void
+TclX_AppendObjResult _ANSI_ARGS_(TCL_VARARGS_DEF(Tcl_Interp *, interpArg));
+
 EXTERN char * 
 TclX_DownShift _ANSI_ARGS_((char       *targetStr,
                             CONST char *sourceStr));
@@ -281,6 +293,16 @@ TclX_AsyncCommandLoop _ANSI_ARGS_((Tcl_Interp *interp,
 #define TCL_STORAGE_CLASS DLLEXPORT
 #endif
 
+/* Removed TclX_Main, use macro instead */
+#define TkX_Main(argc, argv, proc) \
+    TkX_MainEx(argc, argv, proc, Tcl_CreateInterp())
+
+EXTERN void
+TkX_MainEx _ANSI_ARGS_((int            argc,
+                      char             **argv,
+                      Tcl_AppInitProc  *appInitProc,
+		      Tcl_Interp       *interp));
+
 EXTERN int
 Tkx_Init _ANSI_ARGS_((Tcl_Interp  *interp));
 
@@ -290,11 +312,6 @@ Tkx_InitStandAlone _ANSI_ARGS_((Tcl_Interp *interp));
 EXTERN int
 Tkx_SafeInit _ANSI_ARGS_((Tcl_Interp *interp));
 
-EXTERN void
-TkX_Main _ANSI_ARGS_((int               argc,
-                      char            **argv,
-                      Tcl_AppInitProc  *appInitProc));
-
 /*
  * These are for Windows only.
  */
