@@ -582,7 +582,7 @@ SetMatchInfoVar (interp, scanData)
     }
     regExpPtr = (TclRegexp *) scanData->matchPtr->regExp;
 
-    for (idx = 0; idx < regExpPtr->re.re_nsub; idx++) {
+    for (idx = 0; (unsigned int) idx < regExpPtr->re.re_nsub; idx++) {
 	start = regExpPtr->matches[idx+1].rm_so;
 	end = regExpPtr->matches[idx+1].rm_eo;
 
@@ -689,8 +689,10 @@ ScanFile (interp, contextPtr, channel)
              data.matchPtr != NULL; 
              data.matchPtr = data.matchPtr->nextMatchDefPtr) {
 
-            matchStat = TclRegExpExecUniChar(interp, data.matchPtr->regExp,
-                                             data.uniLine, data.uniLineLen, -1, 0);
+            matchStat = Tcl_RegExpExec(interp,
+		    data.matchPtr->regExp,
+		    Tcl_DStringValue(&lineBuf),
+		    Tcl_DStringValue(&lineBuf));
             if (matchStat < 0) {
                 result = TCL_ERROR;
                 goto scanExit;
