@@ -354,6 +354,10 @@ int
 Tclx_Init (interp)
     Tcl_Interp *interp;
 {
+    if (Tcl_InitStubs(interp, "8.0", 0) == NULL) {
+	abort();
+    }
+
     if (InitSetup (interp) == TCL_ERROR)
         goto errorExit;
 
@@ -401,5 +405,25 @@ Tclx_SafeInit (interp)
                      "\n    (while initializing safe TclX)");
     return TCL_ERROR;
 }
+
+/*-----------------------------------------------------------------------------
+ * Tclx_InitTclStubs --
+ *
+ *   Initialize Tcl stubs inside of the TclX dynamic library.
+ *-----------------------------------------------------------------------------
+ */
+char *
+TclX_InitTclStubs (interp, version, exact)
+    Tcl_Interp *interp;
+    char *version;
+    int exact;
+{
+    char *actualVersion;
 
-
+    actualVersion = Tcl_InitStubs(interp, version, exact);
+    if (actualVersion == NULL) {
+	return NULL;
+    } else {
+	return actualVersion;
+    }
+}
