@@ -4,7 +4,7 @@
  * Function to add the Extented Tcl library commands into an interpreter. This
  * also sets the Tcl auto_path, tcl_library and tclx_library variable.
  *-----------------------------------------------------------------------------
- * Copyright 1991-1997 Karl Lehenbauer and Mark Diekhans.
+ * Copyright 1991-1999 Karl Lehenbauer and Mark Diekhans.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation for any purpose and without fee is hereby granted, provided
@@ -13,7 +13,7 @@
  * software for any purpose.  It is provided "as is" without express or
  * implied warranty.
  *-----------------------------------------------------------------------------
- * $Id: tclXlibInit.c,v 8.1 1997/04/17 04:58:44 markd Exp $
+ * $Id$
  *-----------------------------------------------------------------------------
  */
 
@@ -31,9 +31,7 @@ int
 Tclxlib_Init (interp)
     Tcl_Interp *interp;
 {
-    TclX_LibraryInit (interp);
-
-    return TCL_OK;
+    return TclX_LibraryInit (interp);
 }
 
 
