@@ -4,7 +4,7 @@
 # Tcl help command. (see TclX manual)
 # 
 #------------------------------------------------------------------------------
-# Copyright 1992-1997 Karl Lehenbauer and Mark Diekhans.
+# Copyright 1992-1999 Karl Lehenbauer and Mark Diekhans.
 #
 # Permission to use, copy, modify, and distribute this software and its
 # documentation for any purpose and without fee is hereby granted, provided
@@ -18,7 +18,7 @@
 # being the merger of all "help" directories found along the $auto_path
 # variable.
 #------------------------------------------------------------------------------
-# $Id: help.tcl,v 8.6 1997/08/23 18:55:22 markd Exp $
+# $Id$
 #------------------------------------------------------------------------------
 #
 # FIX: Convert this to use namespaces.
@@ -108,6 +108,18 @@ namespace eval TclXHelp {
                 return [list $dir/$pathName]
             }
         }
+
+	# Not found, try to find a file matching only the file tail,
+	# for example if --> <helpDir>/tcl/control/if.
+
+	set fileTail [file tail $pathName]
+        foreach dir [RootDirs] {
+	    set fileName [exec find $dir -name $fileTail | head -1]
+	    if {$fileName != {}} {
+                return [list $fileName]
+	    }
+	}
+
         error "\"$pathName\" does not exist" {} \
             [list TCLXHELP NOEXIST $pathName]
     }
@@ -200,13 +212,16 @@ namespace eval TclXHelp {
     proc DisplayPage filePath {
 
         set inFH [open $filePath r]
-        while {[gets $inFH fileBuf] >= 0} {
-            if {![Display $fileBuf]} {
-                break
+        try_eval {
+            while {[gets $inFH fileBuf] >= 0} {
+                if {![Display $fileBuf]} {
+                    break
+                }
             }
+        } {} {
+            close $inFH
         }
-        close $inFH
-    }    
+    }
 
     #--------------------------------------------------------------------------
     # Display a list of file names in a column format. This use columns of 14 
@@ -331,8 +346,11 @@ proc apropos {regexp} {
     foreach dir [TclXHelp::RootDirs] {
         foreach brief [glob -nocomplain $dir/*.brf] {
             set briefFH [open $brief]
-            scanfile $ch $briefFH
-            close $briefFH
+            try_eval {
+                scanfile $ch $briefFH
+            } {} {
+                close $briefFH
+            }
             if $stop break
         }
         if $stop break
