@@ -36,11 +36,6 @@ int
 main (int    argc,
       char **argv)
 {
-
-#ifndef BORLAND
-    TclX_SplitWinCmdLine (&argc, &argv);
-#endif
-
     TclX_Main (argc, argv, Tcl_AppInit);
     return 0;                   /* Needed only to prevent compiler warning. */
 }
