@@ -27,17 +27,6 @@
 #include <malloc.h>
 #include <locale.h>
 
-/*
- * The following declarations refer to internal Tk routines.  These
- * interfaces are available for use, but are not supported.
- */
-
-EXTERN void
-TkConsoleCreate (void);
-
-EXTERN int
-TkConsoleInit (Tcl_Interp *interp);
-
 
 /*-----------------------------------------------------------------------------
  * WinMain --
@@ -54,7 +43,6 @@ WinMain(hInstance, hPrevInstance, lpszCmdLine, nCmdShow)
 {
     char **argv;
     int argc;
-    char buffer [MAX_PATH];
 
     /*
      * Set up the default locale to be standard "C" locale so parsing
@@ -71,21 +59,6 @@ WinMain(hInstance, hPrevInstance, lpszCmdLine, nCmdShow)
      */
     SetMessageQueue(64);
 
-    /*
-     * Create the console channels and install them as the standard
-     * channels.  All I/O will be discarded until TkConsoleInit is
-     * called to attach the console to a text widget.
-     */
-    TkConsoleCreate();
-
-    /*
-     * Parse the command line. Since Windows programs don't get passed the
-     * command name as the first argument, we need to fetch it explicitly.
-     */
-    TclX_SplitWinCmdLine (&argc, &argv);
-    GetModuleFileName (NULL, buffer, sizeof (buffer));
-    argv[0] = buffer;
-
     TkX_Main(argc, argv, Tcl_AppInit);
 
     return 0;                   /* Needed only to prevent compiler warning. */
@@ -109,7 +82,6 @@ Tcl_AppInit (Tcl_Interp *interp)
     if (Tcl_Init (interp) == TCL_ERROR) {
         goto errorExit;
     }
-
     if (Tclx_Init(interp) == TCL_ERROR) {
         goto errorExit;
     }
@@ -125,6 +97,13 @@ Tcl_AppInit (Tcl_Interp *interp)
     }
     Tcl_StaticPackage(interp, "Tkx", Tkx_Init, Tkx_SafeInit);
 
+    /*
+     * Create the console channels and install them as the standard
+     * channels.  All I/O will be discarded until Tk_CreateConsoleWindow
+     * is called to attach the console to a text widget.
+     */
+    Tk_InitConsoleChannels(interp);
+    
     /*
      * Initialize the console for interactive applications.
      */
